==> barbican-2024.2.6+6b985e51b.tgz: barbican/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- Use more standard DB config setting

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Added post-install and post-upgrade helm hook for Jobs
- 0.2.0 Remove support for releases before T
- 0.2.1 Use policies in yaml format
- 0.2.2 Add helm hook conditional
- 0.2.3 Add support for master kek rotation
- 0.2.4 Add Ussuri release support
- 0.2.5 Add Victoria and Wallaby releases support
- 0.2.6 Allow Barbican to talk to Mariadb over TLS
- 0.2.7 Fix db connection key name
- 0.2.8 Update htk requirements repo
- 0.2.9 Removed default policy in favor in code policy
- 0.2.10 Enable taint toleration for Openstack services
- 0.2.11 Fix job annotations for db init job
- 0.2.12 Remove older values overrides
- 0.2.13 Migrated PodDisruptionBudget resource to policy/v1 API version
- 0.2.14 Add Xena and Yoga values overrides
- 0.2.15 Added OCI registry authentication
- 0.2.16 Distinguish between port number of internal endpoint and binding port number
- 0.2.17 Use HTTP probe instead of TCP probe
- 0.2.18 Support TLS for ks jobs
- 0.2.19 Support SSL offloading at reverse proxy for internal and admin endpoints
- 0.3.0 Remove support for Train and Ussuri
- 0.3.1 Replace node-role.kubernetes.io/master with control-plane
- 0.3.2 Define service_type in keystone_authtoken to support application credentials with access rules
- 0.3.3 Add Zed overrides
- 0.3.4 Add 2023.1 overrides
- 0.3.5 Add Ubuntu Jammy overrides
- 0.3.6 Add 2023.2 Ubuntu Jammy overrides
- 0.3.7 Fix TLS connection to rabbitmq, and generate barbican certificate
- 0.3.8 Make barbican TLS configuration granular
- 0.3.9 Enable custom annotations for Openstack pods
- 0.3.10 Add 2024.1 overrides
- 0.3.11 Enable custom annotations for Openstack secrets
- 0.3.12 Update images used by default
- 0.3.13 Sync uWSGI config to other services
- 0.3.14 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.3.15 Add 2024.2 Ubuntu Jammy overrides
- 0.3.16 Add livenessProbe and change path in probe
- 0.3.17 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

==> barbican-2025.1.4+35052e51b.tgz: barbican/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

- Removed the autocommit option, which has been deprecated
  since SQLAlchemy 2.0.

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- Use more standard DB config setting

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Added post-install and post-upgrade helm hook for Jobs
- 0.2.0 Remove support for releases before T
- 0.2.1 Use policies in yaml format
- 0.2.2 Add helm hook conditional
- 0.2.3 Add support for master kek rotation
- 0.2.4 Add Ussuri release support
- 0.2.5 Add Victoria and Wallaby releases support
- 0.2.6 Allow Barbican to talk to Mariadb over TLS
- 0.2.7 Fix db connection key name
- 0.2.8 Update htk requirements repo
- 0.2.9 Removed default policy in favor in code policy
- 0.2.10 Enable taint toleration for Openstack services
- 0.2.11 Fix job annotations for db init job
- 0.2.12 Remove older values overrides
- 0.2.13 Migrated PodDisruptionBudget resource to policy/v1 API version
- 0.2.14 Add Xena and Yoga values overrides
- 0.2.15 Added OCI registry authentication
- 0.2.16 Distinguish between port number of internal endpoint and binding port number
- 0.2.17 Use HTTP probe instead of TCP probe
- 0.2.18 Support TLS for ks jobs
- 0.2.19 Support SSL offloading at reverse proxy for internal and admin endpoints
- 0.3.0 Remove support for Train and Ussuri
- 0.3.1 Replace node-role.kubernetes.io/master with control-plane
- 0.3.2 Define service_type in keystone_authtoken to support application credentials with access rules
- 0.3.3 Add Zed overrides
- 0.3.4 Add 2023.1 overrides
- 0.3.5 Add Ubuntu Jammy overrides
- 0.3.6 Add 2023.2 Ubuntu Jammy overrides
- 0.3.7 Fix TLS connection to rabbitmq, and generate barbican certificate
- 0.3.8 Make barbican TLS configuration granular
- 0.3.9 Enable custom annotations for Openstack pods
- 0.3.10 Add 2024.1 overrides
- 0.3.11 Enable custom annotations for Openstack secrets
- 0.3.12 Update images used by default
- 0.3.13 Sync uWSGI config to other services
- 0.3.14 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.3.15 Add 2024.2 Ubuntu Jammy overrides
- 0.3.16 Add livenessProbe and change path in probe
- 0.3.17 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle
